==> aio_celery-0.1.0-py3-none-any.whl: aio_celery/__main__.py <==
import argparse
import asyncio

from . import __version__
from .worker import run


def main() -> None:
    """
    Main entrypoint of the taskiq.
    """
    parser = argparse.ArgumentParser(
        formatter_class=argparse.RawDescriptionHelpFormatter,
        description=(
            "CLI for %(prog)s\n\n"
            "Examples\n"
            "--------\n"
            "$ %(prog)s --app=proj:app worker\n"
            "$ %(prog)s -A proj:app worker -Q hipri,lopri\n"
            "$ %(prog)s -A proj:app worker --concurrency=50000\n"
        ),
    )
    parser.add_argument(
        "-A",
        "--app",
        help=(
            "Where to search for application instance. "
            "This string must be specified in 'module.module:variable' format."
        ),
    )
    parser.add_argument(
        "-V",
        "--version",
        dest="version",
        action="store_true",
        help="print current %(prog)s version and exit",
    )
    subparsers = parser.add_subparsers(
        title="Available subcommands",
        metavar="",
        dest="subcommand",
    )
    worker = subparsers.add_parser(
        "worker",
        help="Run worker",
        description="Run worker",
        formatter_class=argparse.ArgumentDefaultsHelpFormatter,
    )
    worker.add_argument(
        "-c",
        "--concurrency",
        type=int,
        default=10_000,
        help="Maximum simultaneous async tasks",
    )
    worker.add_argument(
        "-Q",
        "--queues",
        help="Comma separated list of queues",
    )

    args = parser.parse_args()

    if args.version:
        print(__version__)
        return

    if args.subcommand is None:
        parser.print_help()
        return

    if args.app is None:
        parser.print_help()
        return

    asyncio.run(run(args))


if __name__ == "__main__":
    main()

==> aio_celery-0.2.0-py3-none-any.whl: aio_celery/__main__.py <==
import argparse
import asyncio
import sys

from . import __version__
from .worker import run


def main() -> None:
    """
    Main entrypoint of aio_celery.
    """
    parser = argparse.ArgumentParser(
        prog="aio_celery",
        formatter_class=argparse.RawDescriptionHelpFormatter,
        description=(
            "CLI for aio_celery\n\n"
            "Examples\n"
            "--------\n"
            "$ %(prog)s worker proj:app\n"
            "$ %(prog)s worker -Q high,low proj:app\n"
            "$ %(prog)s worker --concurrency=50000 proj:app\n"
        ),
    )
    parser.add_argument(
        "-V",
        "--version",
        dest="version",
        action="store_true",
        help="print current aio_celery version and exit",
    )
    subparsers = parser.add_subparsers(
        title="Available subcommands",
        metavar="",
        dest="subcommand",
    )
    worker = subparsers.add_parser(
        "worker",
        help="Run worker",
        description="Run worker",
        formatter_class=argparse.ArgumentDefaultsHelpFormatter,
    )
    worker.add_argument(
        "app",
        help=(
            "Where to search for application instance. "
            "This string must be specified in 'module.module:variable' format."
        ),
    )
    worker.add_argument(
        "-c",
        "--concurrency",
        type=int,
        default=10_000,
        help="Maximum simultaneous async tasks",
    )
    worker.add_argument(
        "-Q",
        "--queues",
        help="Comma separated list of queues",
    )

    args = parser.parse_args()

    if args.version:
        print(__version__)
        return

    if args.subcommand is None:
        parser.print_help()
        return

    if not (0 < args.concurrency <= 65535):
        print(
            "concurrency must be between 1 and 65535 "
            "(latter is maximum AMQP 0-9-1 prefetch count)",
            file=sys.stderr,
        )
        sys.exit(2)

    asyncio.run(run(args))


if __name__ == "__main__":
    main()
